<?php

namespace B\Realestate\Policies;

use Litepie\User\Contracts\UserPolicy;
use B\Realestate\Models\Pr;

class PrPolicy
{

    /**
     * Determine if the given user can view the pr.
     *
     * @param UserPolicy $user
     * @param Pr $pr
     *
     * @return bool
     */
    public function view(UserPolicy $user, Pr $pr)
    {
        if ($user->canDo('realestate.pr.view') && $user->isAdmin()) {
            return true;
        }

        return $pr->user_id == user_id() && $pr->user_type == user_type();
    }

    /**
     * Determine if the given user can create a pr.
     *
     * @param UserPolicy $user
     * @param Pr $pr
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('realestate.pr.create');
    }

    /**
     * Determine if the given user can update the given pr.
     *
     * @param UserPolicy $user
     * @param Pr $pr
     *
     * @return bool
     */
    public function update(UserPolicy $user, Pr $pr)
    {
        if ($user->canDo('realestate.pr.edit') && $user->isAdmin()) {
            return true;
        }

        return $pr->user_id == user_id() && $pr->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given pr.
     *
     * @param UserPolicy $user
     * @param Pr $pr
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Pr $pr)
    {
        return $pr->user_id == user_id() && $pr->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given pr.
     *
     * @param UserPolicy $user
     * @param Pr $pr
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Pr $pr)
    {
        if ($user->canDo('realestate.pr.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given pr.
     *
     * @param UserPolicy $user
     * @param Pr $pr
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Pr $pr)
    {
        if ($user->canDo('realestate.pr.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
